Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FizzBuzz ¶
FizzBuzz returns a channel that emits numbers starting from 1 until the context is cancelled with multipleReplacements done multipleReplacements should be a map, where each multiple to be replaced is the key and its replacement is the corresponding value, e.g. map[int]string{3: "Fizz", 5: "Buzz"} for the classic example of this problem.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.